/********************************************************************************
** Form generated from reading UI file 'semanticinfodialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEMANTICINFODIALOG_H
#define UI_SEMANTICINFODIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <lib/semanticinfo/tagwidget.h>

QT_BEGIN_NAMESPACE

class Ui_SemanticInfoDialog
{
public:
    QVBoxLayout *verticalLayout;
    Gwenview::TagWidget *mTagWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *mPreviousButton;
    QPushButton *mNextButton;
    QDialogButtonBox *mButtonBox;

    void setupUi(QWidget *SemanticInfoDialog)
    {
        if (SemanticInfoDialog->objectName().isEmpty())
            SemanticInfoDialog->setObjectName("SemanticInfoDialog");
        SemanticInfoDialog->resize(323, 355);
        verticalLayout = new QVBoxLayout(SemanticInfoDialog);
        verticalLayout->setObjectName("verticalLayout");
        mTagWidget = new Gwenview::TagWidget(SemanticInfoDialog);
        mTagWidget->setObjectName("mTagWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mTagWidget->sizePolicy().hasHeightForWidth());
        mTagWidget->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(mTagWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mPreviousButton = new QPushButton(SemanticInfoDialog);
        mPreviousButton->setObjectName("mPreviousButton");

        horizontalLayout->addWidget(mPreviousButton);

        mNextButton = new QPushButton(SemanticInfoDialog);
        mNextButton->setObjectName("mNextButton");

        horizontalLayout->addWidget(mNextButton);

        mButtonBox = new QDialogButtonBox(SemanticInfoDialog);
        mButtonBox->setObjectName("mButtonBox");
        mButtonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(mButtonBox);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(SemanticInfoDialog);

        QMetaObject::connectSlotsByName(SemanticInfoDialog);
    } // setupUi

    void retranslateUi(QWidget *SemanticInfoDialog)
    {
        SemanticInfoDialog->setWindowTitle(tr2i18n("Tag Editor", nullptr));
        mPreviousButton->setText(tr2i18n("Previous", nullptr));
        mNextButton->setText(tr2i18n("Next", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SemanticInfoDialog: public Ui_SemanticInfoDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEMANTICINFODIALOG_H

