/********************************************************************************
** Form generated from reading UI file 'startmainpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STARTMAINPAGE_H
#define UI_STARTMAINPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <kfileplacesview.h>
#include <klocalizedstring.h>
#include <lib/thumbnailview/thumbnailview.h>

QT_BEGIN_NAMESPACE

class Ui_StartMainPage
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *verticalLayout_4;
    QLabel *mHistoryDisabledLabel;
    QTabWidget *mHistoryWidget;
    QWidget *mRecentFoldersTab;
    QVBoxLayout *verticalLayout_5;
    Gwenview::ThumbnailView *mRecentFoldersView;
    QWidget *mRecentFilesTab;
    QVBoxLayout *verticalLayout_6;
    Gwenview::ThumbnailView *mRecentFilesView;
    QFrame *separator;
    QTabWidget *mPlacesTagsWidget;
    KFilePlacesView *mBookmarksView;
    QWidget *tagsTab;
    QVBoxLayout *verticalLayout;
    QLabel *mTagLabel;
    QListView *mTagView;

    void setupUi(QFrame *StartMainPage)
    {
        if (StartMainPage->objectName().isEmpty())
            StartMainPage->setObjectName("StartMainPage");
        StartMainPage->resize(584, 618);
        StartMainPage->setAutoFillBackground(true);
        StartMainPage->setFrameShape(QFrame::StyledPanel);
        StartMainPage->setFrameShadow(QFrame::Sunken);
        horizontalLayout = new QHBoxLayout(StartMainPage);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout_4 = new QVBoxLayout();
        verticalLayout_4->setObjectName("verticalLayout_4");
        mHistoryDisabledLabel = new QLabel(StartMainPage);
        mHistoryDisabledLabel->setObjectName("mHistoryDisabledLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mHistoryDisabledLabel->sizePolicy().hasHeightForWidth());
        mHistoryDisabledLabel->setSizePolicy(sizePolicy);
        mHistoryDisabledLabel->setAlignment(Qt::AlignHCenter|Qt::AlignTop);

        verticalLayout_4->addWidget(mHistoryDisabledLabel);

        mHistoryWidget = new QTabWidget(StartMainPage);
        mHistoryWidget->setObjectName("mHistoryWidget");
        mHistoryWidget->setDocumentMode(true);
        mRecentFoldersTab = new QWidget();
        mRecentFoldersTab->setObjectName("mRecentFoldersTab");
        verticalLayout_5 = new QVBoxLayout(mRecentFoldersTab);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        mRecentFoldersView = new Gwenview::ThumbnailView(mRecentFoldersTab);
        mRecentFoldersView->setObjectName("mRecentFoldersView");
        mRecentFoldersView->setEditTriggers(QAbstractItemView::NoEditTriggers);

        verticalLayout_5->addWidget(mRecentFoldersView);

        mHistoryWidget->addTab(mRecentFoldersTab, QString());
        mRecentFilesTab = new QWidget();
        mRecentFilesTab->setObjectName("mRecentFilesTab");
        verticalLayout_6 = new QVBoxLayout(mRecentFilesTab);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(0, 0, 0, 0);
        mRecentFilesView = new Gwenview::ThumbnailView(mRecentFilesTab);
        mRecentFilesView->setObjectName("mRecentFilesView");
        mRecentFilesView->setEditTriggers(QAbstractItemView::NoEditTriggers);

        verticalLayout_6->addWidget(mRecentFilesView);

        mHistoryWidget->addTab(mRecentFilesTab, QString());

        verticalLayout_4->addWidget(mHistoryWidget);


        horizontalLayout->addLayout(verticalLayout_4);

        separator = new QFrame(StartMainPage);
        separator->setObjectName("separator");
        separator->setFrameShape(QFrame::VLine);

        horizontalLayout->addWidget(separator);

        mPlacesTagsWidget = new QTabWidget(StartMainPage);
        mPlacesTagsWidget->setObjectName("mPlacesTagsWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mPlacesTagsWidget->sizePolicy().hasHeightForWidth());
        mPlacesTagsWidget->setSizePolicy(sizePolicy1);
        mPlacesTagsWidget->setDocumentMode(true);
        mBookmarksView = new KFilePlacesView();
        mBookmarksView->setObjectName("mBookmarksView");
        mBookmarksView->viewport()->setProperty("cursor", QVariant(QCursor(Qt::CursorShape::PointingHandCursor)));
        mBookmarksView->setFrameShape(QFrame::NoFrame);
        mPlacesTagsWidget->addTab(mBookmarksView, QString());
        tagsTab = new QWidget();
        tagsTab->setObjectName("tagsTab");
        verticalLayout = new QVBoxLayout(tagsTab);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        mTagLabel = new QLabel(tagsTab);
        mTagLabel->setObjectName("mTagLabel");
        mTagLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        mTagLabel->setWordWrap(true);

        verticalLayout->addWidget(mTagLabel);

        mTagView = new QListView(tagsTab);
        mTagView->setObjectName("mTagView");
        mTagView->viewport()->setProperty("cursor", QVariant(QCursor(Qt::CursorShape::PointingHandCursor)));
        mTagView->setFrameShape(QFrame::NoFrame);
        mTagView->setIconSize(QSize(32, 32));

        verticalLayout->addWidget(mTagView);

        mPlacesTagsWidget->addTab(tagsTab, QString());

        horizontalLayout->addWidget(mPlacesTagsWidget);


        retranslateUi(StartMainPage);

        mHistoryWidget->setCurrentIndex(0);
        mPlacesTagsWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(StartMainPage);
    } // setupUi

    void retranslateUi(QFrame *StartMainPage)
    {
        mHistoryDisabledLabel->setText(tr2i18n("History has been disabled.", nullptr));
        mHistoryWidget->setTabText(mHistoryWidget->indexOf(mRecentFoldersTab), tr2i18n("Recent Folders", nullptr));
        mHistoryWidget->setTabText(mHistoryWidget->indexOf(mRecentFilesTab), tr2i18n("Recent Files", nullptr));
        mPlacesTagsWidget->setTabText(mPlacesTagsWidget->indexOf(mBookmarksView), tr2i18n("Places", nullptr));
        mTagLabel->setText(tr2i18n("Browsing by tags is not available. Make sure Nepomuk is properly installed on your computer.", nullptr));
        mPlacesTagsWidget->setTabText(mPlacesTagsWidget->indexOf(tagsTab), tr2i18n("Tags", nullptr));
        (void)StartMainPage;
    } // retranslateUi

};

namespace Ui {
    class StartMainPage: public Ui_StartMainPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STARTMAINPAGE_H

