/****************************************************************************
** Meta object code from reading C++ file 'abstractimageview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.07.90/lib/documentview/abstractimageview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractimageview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::AbstractImageView::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::AbstractImageView",
        "zoomToFitChanged",
        "",
        "zoomToFillChanged",
        "zoomChanged",
        "zoomInRequested",
        "QPointF",
        "zoomOutRequested",
        "scrollPosChanged",
        "completed",
        "previousImageRequested",
        "nextImageRequested",
        "toggleFullScreenRequested",
        "updateCursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zoomToFitChanged'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'zoomToFillChanged'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(qreal)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'zoomInRequested'
        QtMocHelpers::SignalData<void(const QPointF &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'zoomOutRequested'
        QtMocHelpers::SignalData<void(const QPointF &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'scrollPosChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousImageRequested'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextImageRequested'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toggleFullScreenRequested'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateCursor'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractImageView, qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::AbstractImageView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>.metaTypes,
    nullptr
} };

void Gwenview::AbstractImageView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractImageView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zoomToFitChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->zoomToFillChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 3: _t->zoomInRequested((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 4: _t->zoomOutRequested((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 5: _t->scrollPosChanged(); break;
        case 6: _t->completed(); break;
        case 7: _t->previousImageRequested(); break;
        case 8: _t->nextImageRequested(); break;
        case 9: _t->toggleFullScreenRequested(); break;
        case 10: _t->updateCursor(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)(bool )>(_a, &AbstractImageView::zoomToFitChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)(bool )>(_a, &AbstractImageView::zoomToFillChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)(qreal )>(_a, &AbstractImageView::zoomChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)(const QPointF & )>(_a, &AbstractImageView::zoomInRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)(const QPointF & )>(_a, &AbstractImageView::zoomOutRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)()>(_a, &AbstractImageView::scrollPosChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)()>(_a, &AbstractImageView::completed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)()>(_a, &AbstractImageView::previousImageRequested, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)()>(_a, &AbstractImageView::nextImageRequested, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractImageView::*)()>(_a, &AbstractImageView::toggleFullScreenRequested, 9))
            return;
    }
}

const QMetaObject *Gwenview::AbstractImageView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::AbstractImageView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview17AbstractImageViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsWidget::qt_metacast(_clname);
}

int Gwenview::AbstractImageView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::AbstractImageView::zoomToFitChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Gwenview::AbstractImageView::zoomToFillChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Gwenview::AbstractImageView::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Gwenview::AbstractImageView::zoomInRequested(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Gwenview::AbstractImageView::zoomOutRequested(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Gwenview::AbstractImageView::scrollPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Gwenview::AbstractImageView::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Gwenview::AbstractImageView::previousImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Gwenview::AbstractImageView::nextImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Gwenview::AbstractImageView::toggleFullScreenRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
