// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "gwenview_exiv2_debug.h"


Q_LOGGING_CATEGORY(GWENVIEW_EXIV2_LOG, "org.kde.kdegraphics.gwenview.exiv2", QtInfoMsg)

