// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "gwenview_importer_debug.h"


Q_LOGGING_CATEGORY(GWENVIEW_IMPORTER_LOG, "org.kde.kdegraphics.gwenview.importer", QtInfoMsg)

