/****************************************************************************
** Meta object code from reading C++ file 'documentview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../gwenview-26.07.90/lib/documentview/documentview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'documentview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Gwenview12DocumentViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Gwenview::DocumentView::qt_create_metaobjectdata<qt_meta_tag_ZN8Gwenview12DocumentViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Gwenview::DocumentView",
        "completed",
        "",
        "previousImageRequested",
        "nextImageRequested",
        "openUrlRequested",
        "QUrl",
        "openDirUrlRequested",
        "captionUpdateRequested",
        "toggleFullScreenRequested",
        "videoFinished",
        "backgroundColorModeChanged",
        "BackgroundColorMode",
        "minimumZoomChanged",
        "zoomChanged",
        "adapterChanged",
        "focused",
        "Gwenview::DocumentView*",
        "zoomToFitChanged",
        "zoomToFillChanged",
        "positionChanged",
        "hudTrashClicked",
        "hudDeselectClicked",
        "fadeInFinished",
        "contextMenuRequested",
        "currentToolChanged",
        "AbstractRasterImageViewTool*",
        "isAnimatedChanged",
        "indicateLoadingToUser",
        "setZoom",
        "setZoomToFit",
        "toggleZoomToFit",
        "setZoomToFill",
        "toggleZoomToFill",
        "zoomActualSize",
        "toggleBirdEyeView",
        "setBackgroundColorMode",
        "colorMode",
        "setPosition",
        "QPoint",
        "hideAndDeleteLater",
        "finishOpenUrl",
        "slotCompleted",
        "slotLoadingFailed",
        "zoomContinuous",
        "delta",
        "QPointF",
        "center",
        "zoomIn",
        "zoomOut",
        "slotZoomChanged",
        "slotBusyChanged",
        "emitHudTrashClicked",
        "emitHudDeselectClicked",
        "emitFocused",
        "slotFadeInFinished",
        "dragThumbnailLoaded",
        "KFileItem",
        "QPixmap",
        "dragThumbnailLoadingFailed",
        "setPinchParameter",
        "timeStamp",
        "zoomGesture",
        "newZoom",
        "pos",
        "rotationsGesture",
        "swipeRight",
        "swipeLeft",
        "panGesture",
        "startDragFromTouch",
        "zoom",
        "zoomToFit",
        "zoomToFill",
        "position",
        "Auto",
        "Light",
        "Neutral",
        "Dark"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'completed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousImageRequested'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextImageRequested'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openUrlRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'openDirUrlRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'captionUpdateRequested'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'toggleFullScreenRequested'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videoFinished'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorModeChanged'
        QtMocHelpers::SignalData<void(enum BackgroundColorMode)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'minimumZoomChanged'
        QtMocHelpers::SignalData<void(qreal)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(qreal)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Signal 'adapterChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'focused'
        QtMocHelpers::SignalData<void(Gwenview::DocumentView *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'zoomToFitChanged'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'zoomToFillChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hudTrashClicked'
        QtMocHelpers::SignalData<void(Gwenview::DocumentView *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'hudDeselectClicked'
        QtMocHelpers::SignalData<void(Gwenview::DocumentView *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'fadeInFinished'
        QtMocHelpers::SignalData<void(Gwenview::DocumentView *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 },
        }}),
        // Signal 'contextMenuRequested'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentToolChanged'
        QtMocHelpers::SignalData<void(AbstractRasterImageViewTool *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Signal 'isAnimatedChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indicateLoadingToUser'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(qreal)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'setZoomToFit'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleZoomToFit'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setZoomToFill'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'toggleZoomToFill'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomActualSize'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleBirdEyeView'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBackgroundColorMode'
        QtMocHelpers::SlotData<void(enum BackgroundColorMode)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 37 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(const QPoint &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 2 },
        }}),
        // Slot 'hideAndDeleteLater'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'finishOpenUrl'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCompleted'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadingFailed'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'zoomContinuous'
        QtMocHelpers::SlotData<void(int, QPointF)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 45 }, { 0x80000000 | 46, 47 },
        }}),
        // Slot 'zoomContinuous'
        QtMocHelpers::SlotData<void(int)>(44, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 45 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void(QPointF)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void(QPointF)>(49, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotZoomChanged'
        QtMocHelpers::SlotData<void(qreal)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'slotBusyChanged'
        QtMocHelpers::SlotData<void(const QUrl &, bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'emitHudTrashClicked'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitHudDeselectClicked'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'emitFocused'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFadeInFinished'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dragThumbnailLoaded'
        QtMocHelpers::SlotData<void(const KFileItem &, const QPixmap &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 }, { 0x80000000 | 58, 2 },
        }}),
        // Slot 'dragThumbnailLoadingFailed'
        QtMocHelpers::SlotData<void(const KFileItem &)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 2 },
        }}),
        // Slot 'setPinchParameter'
        QtMocHelpers::SlotData<void(qint64)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 61 },
        }}),
        // Slot 'zoomGesture'
        QtMocHelpers::SlotData<void(qreal, const QPoint &, qint64)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 63 }, { 0x80000000 | 39, 64 }, { QMetaType::LongLong, 61 },
        }}),
        // Slot 'rotationsGesture'
        QtMocHelpers::SlotData<void(qreal)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 2 },
        }}),
        // Slot 'swipeRight'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'swipeLeft'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'panGesture'
        QtMocHelpers::SlotData<void(const QPointF &)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 45 },
        }}),
        // Slot 'startDragFromTouch'
        QtMocHelpers::SlotData<void(const QPoint &)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 64 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'zoom'
        QtMocHelpers::PropertyData<qreal>(70, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'zoomToFit'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'zoomToFill'
        QtMocHelpers::PropertyData<bool>(72, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'position'
        QtMocHelpers::PropertyData<QPoint>(73, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BackgroundColorMode'
        QtMocHelpers::EnumData<enum BackgroundColorMode>(12, 12, QMC::EnumFlags{}).add({
            {   74, BackgroundColorMode::Auto },
            {   75, BackgroundColorMode::Light },
            {   76, BackgroundColorMode::Neutral },
            {   77, BackgroundColorMode::Dark },
        }),
    };
    return QtMocHelpers::metaObjectData<DocumentView, qt_meta_tag_ZN8Gwenview12DocumentViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Gwenview::DocumentView::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12DocumentViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12DocumentViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Gwenview12DocumentViewE_t>.metaTypes,
    nullptr
} };

void Gwenview::DocumentView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->completed(); break;
        case 1: _t->previousImageRequested(); break;
        case 2: _t->nextImageRequested(); break;
        case 3: _t->openUrlRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->openDirUrlRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->captionUpdateRequested((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->toggleFullScreenRequested(); break;
        case 7: _t->videoFinished(); break;
        case 8: _t->backgroundColorModeChanged((*reinterpret_cast<std::add_pointer_t<enum BackgroundColorMode>>(_a[1]))); break;
        case 9: _t->minimumZoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 10: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 11: _t->adapterChanged(); break;
        case 12: _t->focused((*reinterpret_cast<std::add_pointer_t<Gwenview::DocumentView*>>(_a[1]))); break;
        case 13: _t->zoomToFitChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->zoomToFillChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->positionChanged(); break;
        case 16: _t->hudTrashClicked((*reinterpret_cast<std::add_pointer_t<Gwenview::DocumentView*>>(_a[1]))); break;
        case 17: _t->hudDeselectClicked((*reinterpret_cast<std::add_pointer_t<Gwenview::DocumentView*>>(_a[1]))); break;
        case 18: _t->fadeInFinished((*reinterpret_cast<std::add_pointer_t<Gwenview::DocumentView*>>(_a[1]))); break;
        case 19: _t->contextMenuRequested(); break;
        case 20: _t->currentToolChanged((*reinterpret_cast<std::add_pointer_t<AbstractRasterImageViewTool*>>(_a[1]))); break;
        case 21: _t->isAnimatedChanged(); break;
        case 22: _t->indicateLoadingToUser(); break;
        case 23: _t->setZoom((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 24: _t->setZoomToFit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->toggleZoomToFit(); break;
        case 26: _t->setZoomToFill((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->toggleZoomToFill(); break;
        case 28: _t->zoomActualSize(); break;
        case 29: _t->toggleBirdEyeView(); break;
        case 30: _t->setBackgroundColorMode((*reinterpret_cast<std::add_pointer_t<enum BackgroundColorMode>>(_a[1]))); break;
        case 31: _t->setPosition((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 32: _t->hideAndDeleteLater(); break;
        case 33: _t->finishOpenUrl(); break;
        case 34: _t->slotCompleted(); break;
        case 35: _t->slotLoadingFailed(); break;
        case 36: _t->zoomContinuous((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 37: _t->zoomContinuous((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 38: _t->zoomIn((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 39: _t->zoomIn(); break;
        case 40: _t->zoomOut((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 41: _t->zoomOut(); break;
        case 42: _t->slotZoomChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 43: _t->slotBusyChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 44: _t->emitHudTrashClicked(); break;
        case 45: _t->emitHudDeselectClicked(); break;
        case 46: _t->emitFocused(); break;
        case 47: _t->slotFadeInFinished(); break;
        case 48: _t->dragThumbnailLoaded((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 49: _t->dragThumbnailLoadingFailed((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1]))); break;
        case 50: _t->setPinchParameter((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 51: _t->zoomGesture((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<qint64>>(_a[3]))); break;
        case 52: _t->rotationsGesture((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 53: _t->swipeRight(); break;
        case 54: _t->swipeLeft(); break;
        case 55: _t->panGesture((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 56: _t->startDragFromTouch((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Gwenview::DocumentView* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Gwenview::DocumentView* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Gwenview::DocumentView* >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Gwenview::DocumentView* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::completed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::previousImageRequested, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::nextImageRequested, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(const QUrl & )>(_a, &DocumentView::openUrlRequested, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(const QUrl & )>(_a, &DocumentView::openDirUrlRequested, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(const QString & )>(_a, &DocumentView::captionUpdateRequested, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::toggleFullScreenRequested, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::videoFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(BackgroundColorMode )>(_a, &DocumentView::backgroundColorModeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(qreal )>(_a, &DocumentView::minimumZoomChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(qreal )>(_a, &DocumentView::zoomChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::adapterChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(Gwenview::DocumentView * )>(_a, &DocumentView::focused, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(bool )>(_a, &DocumentView::zoomToFitChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(bool )>(_a, &DocumentView::zoomToFillChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::positionChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(Gwenview::DocumentView * )>(_a, &DocumentView::hudTrashClicked, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(Gwenview::DocumentView * )>(_a, &DocumentView::hudDeselectClicked, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(Gwenview::DocumentView * )>(_a, &DocumentView::fadeInFinished, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::contextMenuRequested, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)(AbstractRasterImageViewTool * )>(_a, &DocumentView::currentToolChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::isAnimatedChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (DocumentView::*)()>(_a, &DocumentView::indicateLoadingToUser, 22))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->zoom(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->zoomToFit(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->zoomToFill(); break;
        case 3: *reinterpret_cast<QPoint*>(_v) = _t->position(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setZoom(*reinterpret_cast<qreal*>(_v)); break;
        case 1: _t->setZoomToFit(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setZoomToFill(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setPosition(*reinterpret_cast<QPoint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Gwenview::DocumentView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Gwenview::DocumentView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Gwenview12DocumentViewE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsWidget::qt_metacast(_clname);
}

int Gwenview::DocumentView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 57)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 57;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Gwenview::DocumentView::completed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Gwenview::DocumentView::previousImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Gwenview::DocumentView::nextImageRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Gwenview::DocumentView::openUrlRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Gwenview::DocumentView::openDirUrlRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Gwenview::DocumentView::captionUpdateRequested(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Gwenview::DocumentView::toggleFullScreenRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Gwenview::DocumentView::videoFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Gwenview::DocumentView::backgroundColorModeChanged(BackgroundColorMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Gwenview::DocumentView::minimumZoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Gwenview::DocumentView::zoomChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void Gwenview::DocumentView::adapterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Gwenview::DocumentView::focused(Gwenview::DocumentView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Gwenview::DocumentView::zoomToFitChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void Gwenview::DocumentView::zoomToFillChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void Gwenview::DocumentView::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Gwenview::DocumentView::hudTrashClicked(Gwenview::DocumentView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void Gwenview::DocumentView::hudDeselectClicked(Gwenview::DocumentView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void Gwenview::DocumentView::fadeInFinished(Gwenview::DocumentView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Gwenview::DocumentView::contextMenuRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Gwenview::DocumentView::currentToolChanged(AbstractRasterImageViewTool * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void Gwenview::DocumentView::isAnimatedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Gwenview::DocumentView::indicateLoadingToUser()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
