// This file is generated by kconfig_compiler_kf6 from importerconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef GWENVIEW_IMPORTERCONFIG_H
#define GWENVIEW_IMPORTERCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace Gwenview {

class ImporterConfig : public KConfigSkeleton
{
  public:

    static ImporterConfig *self();
    ~ImporterConfig() override;

    /**
      Set DestinationUrl
    */
    static
    void setDestinationUrl( const QUrl & v )
    {
      if (!self()->isDestinationUrlImmutable())
        self()->mDestinationUrl = v;
    }

    /**
      Get DestinationUrl
    */
    static
    QUrl destinationUrl()
    {
      return self()->mDestinationUrl;
    }

    /**
      Is DestinationUrl Immutable
    */
    static
    bool isDestinationUrlImmutable()
    {
      return self()->isImmutable( QStringLiteral( "DestinationUrl" ) );
    }

    /**
      Set AutoRename
    */
    static
    void setAutoRename( bool v )
    {
      if (!self()->isAutoRenameImmutable())
        self()->mAutoRename = v;
    }

    /**
      Get AutoRename
    */
    static
    bool autoRename()
    {
      return self()->mAutoRename;
    }

    /**
      Is AutoRename Immutable
    */
    static
    bool isAutoRenameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoRename" ) );
    }

    /**
      Set AutoRenameFormat
    */
    static
    void setAutoRenameFormat( const QString & v )
    {
      if (!self()->isAutoRenameFormatImmutable())
        self()->mAutoRenameFormat = v;
    }

    /**
      Get AutoRenameFormat
    */
    static
    QString autoRenameFormat()
    {
      return self()->mAutoRenameFormat;
    }

    /**
      Is AutoRenameFormat Immutable
    */
    static
    bool isAutoRenameFormatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "AutoRenameFormat" ) );
    }

  protected:
    ImporterConfig();
    friend class ImporterConfigHelper;


    // General
    QUrl mDestinationUrl;
    bool mAutoRename;
    QString mAutoRenameFormat;
};

}

#endif

