/********************************************************************************
** Form generated from reading UI file 'advancedconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDCONFIGPAGE_H
#define UI_ADVANCEDCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_AdvancedConfigPage
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_LowResourceUsageMode;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_3;
    QLabel *cacheHelpLabel;
    QLabel *label_2;
    QLabel *relativeHelpLabel;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *relativeRenderingIntentRadioButton;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_1;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *perceptualRenderingIntentRadioButton;
    QLabel *perceptualHelpLabel;
    QLabel *colorRenderingLabel;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_HistoryEnabled;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *kcfg_EnableColorManagement;
    QSpacerItem *horizontalSpacer_3;
    QLabel *colorProfileHelpLabel;
    QLabel *colorProfileLabel;

    void setupUi(QWidget *AdvancedConfigPage)
    {
        if (AdvancedConfigPage->objectName().isEmpty())
            AdvancedConfigPage->setObjectName("AdvancedConfigPage");
        AdvancedConfigPage->resize(451, 439);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AdvancedConfigPage->sizePolicy().hasHeightForWidth());
        AdvancedConfigPage->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(AdvancedConfigPage);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_LowResourceUsageMode = new QCheckBox(AdvancedConfigPage);
        kcfg_LowResourceUsageMode->setObjectName("kcfg_LowResourceUsageMode");

        horizontalLayout_2->addWidget(kcfg_LowResourceUsageMode);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 7, 0, 1, 2);

        cacheHelpLabel = new QLabel(AdvancedConfigPage);
        cacheHelpLabel->setObjectName("cacheHelpLabel");
        sizePolicy.setHeightForWidth(cacheHelpLabel->sizePolicy().hasHeightForWidth());
        cacheHelpLabel->setSizePolicy(sizePolicy);
        cacheHelpLabel->setWordWrap(true);

        gridLayout->addWidget(cacheHelpLabel, 1, 1, 1, 1);

        label_2 = new QLabel(AdvancedConfigPage);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        relativeHelpLabel = new QLabel(AdvancedConfigPage);
        relativeHelpLabel->setObjectName("relativeHelpLabel");
        relativeHelpLabel->setWordWrap(true);

        gridLayout->addWidget(relativeHelpLabel, 9, 1, 1, 1);

        label_3 = new QLabel(AdvancedConfigPage);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 3, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        relativeRenderingIntentRadioButton = new QRadioButton(AdvancedConfigPage);
        relativeRenderingIntentRadioButton->setObjectName("relativeRenderingIntentRadioButton");
        relativeRenderingIntentRadioButton->setChecked(true);

        horizontalLayout_3->addWidget(relativeRenderingIntentRadioButton);


        gridLayout->addLayout(horizontalLayout_3, 8, 1, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_7, 10, 0, 1, 2);

        verticalSpacer_1 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_1, 2, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        perceptualRenderingIntentRadioButton = new QRadioButton(AdvancedConfigPage);
        perceptualRenderingIntentRadioButton->setObjectName("perceptualRenderingIntentRadioButton");
        perceptualRenderingIntentRadioButton->setChecked(true);

        horizontalLayout_4->addWidget(perceptualRenderingIntentRadioButton);


        gridLayout->addLayout(horizontalLayout_4, 5, 1, 1, 1);

        perceptualHelpLabel = new QLabel(AdvancedConfigPage);
        perceptualHelpLabel->setObjectName("perceptualHelpLabel");
        perceptualHelpLabel->setWordWrap(true);

        gridLayout->addWidget(perceptualHelpLabel, 6, 1, 1, 1);

        colorRenderingLabel = new QLabel(AdvancedConfigPage);
        colorRenderingLabel->setObjectName("colorRenderingLabel");
        colorRenderingLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(colorRenderingLabel, 5, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_HistoryEnabled = new QCheckBox(AdvancedConfigPage);
        kcfg_HistoryEnabled->setObjectName("kcfg_HistoryEnabled");

        horizontalLayout->addWidget(kcfg_HistoryEnabled);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout, 3, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 4, 0, 1, 2);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        kcfg_EnableColorManagement = new QCheckBox(AdvancedConfigPage);
        kcfg_EnableColorManagement->setObjectName("kcfg_EnableColorManagement");
        kcfg_EnableColorManagement->setChecked(true);

        horizontalLayout_5->addWidget(kcfg_EnableColorManagement);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_5, 11, 1, 1, 1);

        colorProfileHelpLabel = new QLabel(AdvancedConfigPage);
        colorProfileHelpLabel->setObjectName("colorProfileHelpLabel");
        colorProfileHelpLabel->setWordWrap(true);

        gridLayout->addWidget(colorProfileHelpLabel, 12, 1, 1, 1);

        colorProfileLabel = new QLabel(AdvancedConfigPage);
        colorProfileLabel->setObjectName("colorProfileLabel");
        colorProfileLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(colorProfileLabel, 11, 0, 1, 1);

#if QT_CONFIG(shortcut)
        colorRenderingLabel->setBuddy(relativeRenderingIntentRadioButton);
#endif // QT_CONFIG(shortcut)

        retranslateUi(AdvancedConfigPage);

        QMetaObject::connectSlotsByName(AdvancedConfigPage);
    } // setupUi

    void retranslateUi(QWidget *AdvancedConfigPage)
    {
        kcfg_LowResourceUsageMode->setText(tr2i18n("Low resource usage mode", nullptr));
        cacheHelpLabel->setText(tr2i18n("Enable this option if you do not have a lot of disk space. This will avoid storing thumbnails on disk and will prefer embedded thumbnails of lower quality that are faster to load, if available.", nullptr));
        label_2->setText(tr2i18n("Thumbnails:", nullptr));
        relativeHelpLabel->setText(tr2i18n("Squash colors that don't fit within the active color profile's color gamut, leaving other colors untouched", nullptr));
        label_3->setText(tr2i18n("History:", nullptr));
        relativeRenderingIntentRadioButton->setText(tr2i18n("Relative Colorimetric", "@option:Relative Colorimetric rendering intent"));
        perceptualRenderingIntentRadioButton->setText(tr2i18n("Perceptual", "@option:Perceptual rendering intent"));
        perceptualHelpLabel->setText(tr2i18n("Scale all colors equally to fit them within the active color profile's color gamut", nullptr));
        colorRenderingLabel->setText(tr2i18n("Rendering intent:", nullptr));
        kcfg_HistoryEnabled->setText(tr2i18n("Remember folders and URLs", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_EnableColorManagement->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        kcfg_EnableColorManagement->setText(tr2i18n("Enable color management", nullptr));
        colorProfileHelpLabel->setText(tr2i18n("When color management is disabled, Gwenview will convert images to the sRGB color space rather than to the color space it detects for the display. This is only appropriate for displays that are calibrated to the sRGB color space or are known to provide an incorrect color profile.", nullptr));
        colorProfileLabel->setText(tr2i18n("Color management:", nullptr));
        (void)AdvancedConfigPage;
    } // retranslateUi

};

namespace Ui {
    class AdvancedConfigPage: public Ui_AdvancedConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADVANCEDCONFIGPAGE_H

