/********************************************************************************
** Form generated from reading UI file 'resizeimagewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESIZEIMAGEWIDGET_H
#define UI_RESIZEIMAGEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ResizeImageWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *mEstimatedSizeLabel;
    QLabel *label_3;
    QLabel *label_5;
    QLabel *label_2;
    QDoubleSpinBox *mHeightPercentSpinBox;
    QLabel *label_6;
    QSpinBox *mHeightSpinBox;
    QSpinBox *mWidthSpinBox;
    QLabel *mCurrentSizeLabel;
    QLabel *mOriginalWidthLabel;
    QLabel *label_7;
    QCheckBox *mKeepAspectCheckBox;
    QLabel *label_4;
    QLabel *mOriginalHeightLabel;
    QLabel *label;
    QLabel *mEstimatedSize;
    QDoubleSpinBox *mWidthPercentSpinBox;
    QLabel *mCurrentSize;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ResizeImageWidget)
    {
        if (ResizeImageWidget->objectName().isEmpty())
            ResizeImageWidget->setObjectName("ResizeImageWidget");
        ResizeImageWidget->resize(311, 212);
        gridLayout = new QGridLayout(ResizeImageWidget);
        gridLayout->setObjectName("gridLayout");
        mEstimatedSizeLabel = new QLabel(ResizeImageWidget);
        mEstimatedSizeLabel->setObjectName("mEstimatedSizeLabel");
        mEstimatedSizeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mEstimatedSizeLabel, 7, 0, 1, 2);

        label_3 = new QLabel(ResizeImageWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 0, 1, 1, 1);

        label_5 = new QLabel(ResizeImageWidget);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 0, 3, 1, 1);

        label_2 = new QLabel(ResizeImageWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        mHeightPercentSpinBox = new QDoubleSpinBox(ResizeImageWidget);
        mHeightPercentSpinBox->setObjectName("mHeightPercentSpinBox");
        mHeightPercentSpinBox->setEnabled(false);
        mHeightPercentSpinBox->setDecimals(0);
        mHeightPercentSpinBox->setMinimum(1.000000000000000);
        mHeightPercentSpinBox->setMaximum(1000.000000000000000);

        gridLayout->addWidget(mHeightPercentSpinBox, 3, 3, 1, 1);

        label_6 = new QLabel(ResizeImageWidget);
        label_6->setObjectName("label_6");
        label_6->setText(QString::fromUtf8("\342\250\257"));

        gridLayout->addWidget(label_6, 1, 2, 1, 1);

        mHeightSpinBox = new QSpinBox(ResizeImageWidget);
        mHeightSpinBox->setObjectName("mHeightSpinBox");
        mHeightSpinBox->setMinimum(1);
        mHeightSpinBox->setMaximum(99999);

        gridLayout->addWidget(mHeightSpinBox, 2, 3, 1, 1);

        mWidthSpinBox = new QSpinBox(ResizeImageWidget);
        mWidthSpinBox->setObjectName("mWidthSpinBox");
        mWidthSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mWidthSpinBox->setMinimum(1);
        mWidthSpinBox->setMaximum(99999);

        gridLayout->addWidget(mWidthSpinBox, 2, 1, 1, 1);

        mCurrentSizeLabel = new QLabel(ResizeImageWidget);
        mCurrentSizeLabel->setObjectName("mCurrentSizeLabel");
        mCurrentSizeLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(mCurrentSizeLabel, 6, 0, 1, 2);

        mOriginalWidthLabel = new QLabel(ResizeImageWidget);
        mOriginalWidthLabel->setObjectName("mOriginalWidthLabel");
        mOriginalWidthLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mOriginalWidthLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(mOriginalWidthLabel, 1, 1, 1, 1);

        label_7 = new QLabel(ResizeImageWidget);
        label_7->setObjectName("label_7");
        label_7->setText(QString::fromUtf8("\342\250\257"));

        gridLayout->addWidget(label_7, 3, 2, 1, 1);

        mKeepAspectCheckBox = new QCheckBox(ResizeImageWidget);
        mKeepAspectCheckBox->setObjectName("mKeepAspectCheckBox");
        mKeepAspectCheckBox->setChecked(true);

        gridLayout->addWidget(mKeepAspectCheckBox, 4, 1, 1, 3);

        label_4 = new QLabel(ResizeImageWidget);
        label_4->setObjectName("label_4");
        label_4->setText(QString::fromUtf8("\342\250\257"));

        gridLayout->addWidget(label_4, 2, 2, 1, 1);

        mOriginalHeightLabel = new QLabel(ResizeImageWidget);
        mOriginalHeightLabel->setObjectName("mOriginalHeightLabel");
        mOriginalHeightLabel->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByMouse);

        gridLayout->addWidget(mOriginalHeightLabel, 1, 3, 1, 1);

        label = new QLabel(ResizeImageWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 1, 0, 1, 1);

        mEstimatedSize = new QLabel(ResizeImageWidget);
        mEstimatedSize->setObjectName("mEstimatedSize");
        mEstimatedSize->setText(QString::fromUtf8(""));
        mEstimatedSize->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);

        gridLayout->addWidget(mEstimatedSize, 7, 3, 1, 1);

        mWidthPercentSpinBox = new QDoubleSpinBox(ResizeImageWidget);
        mWidthPercentSpinBox->setObjectName("mWidthPercentSpinBox");
        mWidthPercentSpinBox->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        mWidthPercentSpinBox->setDecimals(0);
        mWidthPercentSpinBox->setMinimum(1.000000000000000);
        mWidthPercentSpinBox->setMaximum(1000.000000000000000);

        gridLayout->addWidget(mWidthPercentSpinBox, 3, 1, 1, 1);

        mCurrentSize = new QLabel(ResizeImageWidget);
        mCurrentSize->setObjectName("mCurrentSize");
        mCurrentSize->setText(QString::fromUtf8(""));
        mCurrentSize->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);

        gridLayout->addWidget(mCurrentSize, 6, 3, 1, 1);

        verticalSpacer = new QSpacerItem(0, 18, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 0, 1, 1);

#if QT_CONFIG(shortcut)
        label_2->setBuddy(mWidthSpinBox);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(mWidthSpinBox, mHeightSpinBox);
        QWidget::setTabOrder(mHeightSpinBox, mWidthPercentSpinBox);
        QWidget::setTabOrder(mWidthPercentSpinBox, mHeightPercentSpinBox);
        QWidget::setTabOrder(mHeightPercentSpinBox, mKeepAspectCheckBox);

        retranslateUi(ResizeImageWidget);
        QObject::connect(mKeepAspectCheckBox, &QCheckBox::toggled, mHeightPercentSpinBox, &QDoubleSpinBox::setDisabled);

        QMetaObject::connectSlotsByName(ResizeImageWidget);
    } // setupUi

    void retranslateUi(QWidget *ResizeImageWidget)
    {
        ResizeImageWidget->setWindowTitle(tr2i18n("Resize Image", nullptr));
        mEstimatedSizeLabel->setText(tr2i18n("Estimated new file size:", nullptr));
        label_3->setText(tr2i18n("Width", nullptr));
        label_5->setText(tr2i18n("Height", nullptr));
        label_2->setText(tr2i18n("New size:", nullptr));
        mHeightPercentSpinBox->setSuffix(tr2i18n(" %", nullptr));
        mHeightSpinBox->setSuffix(tr2i18n(" px", nullptr));
        mWidthSpinBox->setSuffix(tr2i18n(" px", nullptr));
        mCurrentSizeLabel->setText(tr2i18n("Current file size:", nullptr));
        mOriginalWidthLabel->setText(QString());
        mKeepAspectCheckBox->setText(tr2i18n("Keep aspect ratio", nullptr));
        mOriginalHeightLabel->setText(QString());
        label->setText(tr2i18n("Current size:", nullptr));
        mWidthPercentSpinBox->setSuffix(tr2i18n(" %", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ResizeImageWidget: public Ui_ResizeImageWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESIZEIMAGEWIDGET_H

