/********************************************************************************
** Form generated from reading UI file 'browsemainpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSEMAINPAGE_H
#define UI_BROWSEMAINPAGE_H

#include <KToolBar>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <ksqueezedtextlabel.h>
#include <lib/statusbartoolbutton.h>
#include <lib/thumbnailview/thumbnailslider.h>
#include <lib/thumbnailview/thumbnailview.h>

QT_BEGIN_NAMESPACE

class Ui_BrowseMainPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    KToolBar *mFullScreenToolBar;
    QWidget *mUrlNavigatorContainer;
    KToolBar *mFullScreenToolBar2;
    Gwenview::ThumbnailView *mThumbnailView;
    QFrame *mFilterFrame;
    QWidget *mStatusBarContainer;
    QHBoxLayout *horizontalLayout;
    Gwenview::StatusBarToolButton *mToggleSideBarButton;
    Gwenview::StatusBarToolButton *mAddFilterButton;
    KSqueezedTextLabel *mDocumentCountLabel;
    Gwenview::ThumbnailSlider *mThumbnailSlider;

    void setupUi(QWidget *BrowseMainPage)
    {
        if (BrowseMainPage->objectName().isEmpty())
            BrowseMainPage->setObjectName("BrowseMainPage");
        BrowseMainPage->resize(264, 267);
        verticalLayout = new QVBoxLayout(BrowseMainPage);
        verticalLayout->setSpacing(0);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        mFullScreenToolBar = new KToolBar(BrowseMainPage);
        mFullScreenToolBar->setObjectName("mFullScreenToolBar");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mFullScreenToolBar->sizePolicy().hasHeightForWidth());
        mFullScreenToolBar->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(mFullScreenToolBar);

        mUrlNavigatorContainer = new QWidget(BrowseMainPage);
        mUrlNavigatorContainer->setObjectName("mUrlNavigatorContainer");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mUrlNavigatorContainer->sizePolicy().hasHeightForWidth());
        mUrlNavigatorContainer->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(mUrlNavigatorContainer);

        mFullScreenToolBar2 = new KToolBar(BrowseMainPage);
        mFullScreenToolBar2->setObjectName("mFullScreenToolBar2");
        sizePolicy.setHeightForWidth(mFullScreenToolBar2->sizePolicy().hasHeightForWidth());
        mFullScreenToolBar2->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(mFullScreenToolBar2);


        verticalLayout->addLayout(horizontalLayout_2);

        mThumbnailView = new Gwenview::ThumbnailView(BrowseMainPage);
        mThumbnailView->setObjectName("mThumbnailView");

        verticalLayout->addWidget(mThumbnailView);

        mFilterFrame = new QFrame(BrowseMainPage);
        mFilterFrame->setObjectName("mFilterFrame");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mFilterFrame->sizePolicy().hasHeightForWidth());
        mFilterFrame->setSizePolicy(sizePolicy2);
        mFilterFrame->setFrameShape(QFrame::StyledPanel);
        mFilterFrame->setFrameShadow(QFrame::Sunken);

        verticalLayout->addWidget(mFilterFrame);

        mStatusBarContainer = new QWidget(BrowseMainPage);
        mStatusBarContainer->setObjectName("mStatusBarContainer");
        horizontalLayout = new QHBoxLayout(mStatusBarContainer);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        mToggleSideBarButton = new Gwenview::StatusBarToolButton(mStatusBarContainer);
        mToggleSideBarButton->setObjectName("mToggleSideBarButton");

        horizontalLayout->addWidget(mToggleSideBarButton);

        mAddFilterButton = new Gwenview::StatusBarToolButton(mStatusBarContainer);
        mAddFilterButton->setObjectName("mAddFilterButton");
        mAddFilterButton->setPopupMode(QToolButton::InstantPopup);

        horizontalLayout->addWidget(mAddFilterButton);

        mDocumentCountLabel = new KSqueezedTextLabel(mStatusBarContainer);
        mDocumentCountLabel->setObjectName("mDocumentCountLabel");
        mDocumentCountLabel->setAlignment(Qt::AlignCenter);
        mDocumentCountLabel->setTextElideMode(Qt::ElideRight);

        horizontalLayout->addWidget(mDocumentCountLabel);

        mThumbnailSlider = new Gwenview::ThumbnailSlider(mStatusBarContainer);
        mThumbnailSlider->setObjectName("mThumbnailSlider");
        sizePolicy.setHeightForWidth(mThumbnailSlider->sizePolicy().hasHeightForWidth());
        mThumbnailSlider->setSizePolicy(sizePolicy);
        mThumbnailSlider->setMinimumSize(QSize(120, 0));

        horizontalLayout->addWidget(mThumbnailSlider);


        verticalLayout->addWidget(mStatusBarContainer);


        retranslateUi(BrowseMainPage);

        QMetaObject::connectSlotsByName(BrowseMainPage);
    } // setupUi

    void retranslateUi(QWidget *BrowseMainPage)
    {
        mAddFilterButton->setText(tr2i18n("Add Filter", nullptr));
        mDocumentCountLabel->setText(QString());
        (void)BrowseMainPage;
    } // retranslateUi

};

namespace Ui {
    class BrowseMainPage: public Ui_BrowseMainPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BROWSEMAINPAGE_H

