/********************************************************************************
** Form generated from reading UI file 'imageviewconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMAGEVIEWCONFIGPAGE_H
#define UI_IMAGEVIEWCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ImageViewConfigPage
{
public:
    QGridLayout *gridLayout;
    QLabel *label_1;
    QHBoxLayout *horizontalLayout_0;
    QRadioButton *surroundingRadioButton;
    QSpacerItem *horizontalSpacer_0;
    QHBoxLayout *horizontalLayout_1;
    QRadioButton *checkBoardRadioButton;
    QSpacerItem *horizontalSpacer_1;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *solidColorRadioButton;
    KColorButton *kcfg_AlphaBackgroundColor;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_1;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_3;
    QRadioButton *mouseWheelScrollRadioButton;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *mouseWheelBrowseRadioButton;
    QSpacerItem *horizontalSpacer_4;
    QHBoxLayout *horizontalLayout_16;
    QRadioButton *mouseWheelZoomRadioButton;
    QSpacerItem *horizontalSpacer_16;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_5;
    QRadioButton *autofitZoomModeRadioButton;
    QSpacerItem *horizontalSpacer_5;
    QHBoxLayout *horizontalLayout_6;
    QRadioButton *keepSameZoomModeRadioButton;
    QSpacerItem *horizontalSpacer_6;
    QHBoxLayout *horizontalLayout_7;
    QRadioButton *individualZoomModeRadioButton;
    QSpacerItem *horizontalSpacer_7;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_8;
    QCheckBox *kcfg_EnlargeSmallerImages;
    QSpacerItem *horizontalSpacer_8;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout_9;
    QRadioButton *glAnimationRadioButton;
    QSpacerItem *horizontalSpacer_9;
    QHBoxLayout *horizontalLayout_10;
    QRadioButton *softwareAnimationRadioButton;
    QSpacerItem *horizontalSpacer_10;
    QHBoxLayout *horizontalLayout_11;
    QRadioButton *noAnimationRadioButton;
    QSpacerItem *horizontalSpacer_11;
    QSpacerItem *verticalSpacer_5;
    QLabel *label_5;
    QSpacerItem *verticalSpacer_6;
    QLabel *label_6;
    QHBoxLayout *horizontalLayout_12;
    QRadioButton *horizontalRadioButton;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *horizontalLayout_13;
    QRadioButton *verticalRadioButton;
    QSpacerItem *horizontalSpacer_13;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_14;
    QSpinBox *kcfg_ThumbnailBarRowCount;
    QSpacerItem *horizontalSpacer_14;
    QSpacerItem *verticalSpacer_7;

    void setupUi(QWidget *ImageViewConfigPage)
    {
        if (ImageViewConfigPage->objectName().isEmpty())
            ImageViewConfigPage->setObjectName("ImageViewConfigPage");
        ImageViewConfigPage->resize(500, 650);
        gridLayout = new QGridLayout(ImageViewConfigPage);
        gridLayout->setObjectName("gridLayout");
        label_1 = new QLabel(ImageViewConfigPage);
        label_1->setObjectName("label_1");
        label_1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_1, 0, 0, 1, 1);

        horizontalLayout_0 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        horizontalLayout_0->setSpacing(6);
#endif
        horizontalLayout_0->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_0->setObjectName("horizontalLayout_0");
        surroundingRadioButton = new QRadioButton(ImageViewConfigPage);
        surroundingRadioButton->setObjectName("surroundingRadioButton");
        surroundingRadioButton->setChecked(true);

        horizontalLayout_0->addWidget(surroundingRadioButton);

        horizontalSpacer_0 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_0->addItem(horizontalSpacer_0);


        gridLayout->addLayout(horizontalLayout_0, 0, 1, 1, 1);

        horizontalLayout_1 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        horizontalLayout_1->setSpacing(6);
#endif
        horizontalLayout_1->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_1->setObjectName("horizontalLayout_1");
        checkBoardRadioButton = new QRadioButton(ImageViewConfigPage);
        checkBoardRadioButton->setObjectName("checkBoardRadioButton");
        checkBoardRadioButton->setChecked(false);

        horizontalLayout_1->addWidget(checkBoardRadioButton);

        horizontalSpacer_1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_1->addItem(horizontalSpacer_1);


        gridLayout->addLayout(horizontalLayout_1, 1, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        horizontalLayout_2->setSpacing(6);
#endif
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        solidColorRadioButton = new QRadioButton(ImageViewConfigPage);
        solidColorRadioButton->setObjectName("solidColorRadioButton");

        horizontalLayout_2->addWidget(solidColorRadioButton);

        kcfg_AlphaBackgroundColor = new KColorButton(ImageViewConfigPage);
        kcfg_AlphaBackgroundColor->setObjectName("kcfg_AlphaBackgroundColor");
        kcfg_AlphaBackgroundColor->setEnabled(false);

        horizontalLayout_2->addWidget(kcfg_AlphaBackgroundColor);

        horizontalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_2, 2, 1, 1, 1);

        verticalSpacer_1 = new QSpacerItem(207, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_1, 3, 1, 1, 1);

        label_2 = new QLabel(ImageViewConfigPage);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 4, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        mouseWheelScrollRadioButton = new QRadioButton(ImageViewConfigPage);
        mouseWheelScrollRadioButton->setObjectName("mouseWheelScrollRadioButton");
        mouseWheelScrollRadioButton->setChecked(true);

        horizontalLayout_3->addWidget(mouseWheelScrollRadioButton);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_3, 4, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        mouseWheelBrowseRadioButton = new QRadioButton(ImageViewConfigPage);
        mouseWheelBrowseRadioButton->setObjectName("mouseWheelBrowseRadioButton");

        horizontalLayout_4->addWidget(mouseWheelBrowseRadioButton);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_4, 5, 1, 1, 1);

        horizontalLayout_16 = new QHBoxLayout();
        horizontalLayout_16->setObjectName("horizontalLayout_16");
        mouseWheelZoomRadioButton = new QRadioButton(ImageViewConfigPage);
        mouseWheelZoomRadioButton->setObjectName("mouseWheelZoomRadioButton");

        horizontalLayout_16->addWidget(mouseWheelZoomRadioButton);

        horizontalSpacer_16 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_16->addItem(horizontalSpacer_16);


        gridLayout->addLayout(horizontalLayout_16, 6, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(207, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 7, 1, 1, 1);

        label_3 = new QLabel(ImageViewConfigPage);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 8, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        autofitZoomModeRadioButton = new QRadioButton(ImageViewConfigPage);
        autofitZoomModeRadioButton->setObjectName("autofitZoomModeRadioButton");
        autofitZoomModeRadioButton->setChecked(true);

        horizontalLayout_5->addWidget(autofitZoomModeRadioButton);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_5);


        gridLayout->addLayout(horizontalLayout_5, 8, 1, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        keepSameZoomModeRadioButton = new QRadioButton(ImageViewConfigPage);
        keepSameZoomModeRadioButton->setObjectName("keepSameZoomModeRadioButton");

        horizontalLayout_6->addWidget(keepSameZoomModeRadioButton);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);


        gridLayout->addLayout(horizontalLayout_6, 9, 1, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        individualZoomModeRadioButton = new QRadioButton(ImageViewConfigPage);
        individualZoomModeRadioButton->setObjectName("individualZoomModeRadioButton");

        horizontalLayout_7->addWidget(individualZoomModeRadioButton);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_7);


        gridLayout->addLayout(horizontalLayout_7, 10, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(207, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 11, 1, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        kcfg_EnlargeSmallerImages = new QCheckBox(ImageViewConfigPage);
        kcfg_EnlargeSmallerImages->setObjectName("kcfg_EnlargeSmallerImages");

        horizontalLayout_8->addWidget(kcfg_EnlargeSmallerImages);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_8);


        gridLayout->addLayout(horizontalLayout_8, 12, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(204, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 13, 1, 1, 1);

        label_4 = new QLabel(ImageViewConfigPage);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_4, 14, 0, 1, 1);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        glAnimationRadioButton = new QRadioButton(ImageViewConfigPage);
        glAnimationRadioButton->setObjectName("glAnimationRadioButton");
        glAnimationRadioButton->setChecked(true);

        horizontalLayout_9->addWidget(glAnimationRadioButton);

        horizontalSpacer_9 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_9);


        gridLayout->addLayout(horizontalLayout_9, 14, 1, 1, 1);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        softwareAnimationRadioButton = new QRadioButton(ImageViewConfigPage);
        softwareAnimationRadioButton->setObjectName("softwareAnimationRadioButton");

        horizontalLayout_10->addWidget(softwareAnimationRadioButton);

        horizontalSpacer_10 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_10);


        gridLayout->addLayout(horizontalLayout_10, 15, 1, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        noAnimationRadioButton = new QRadioButton(ImageViewConfigPage);
        noAnimationRadioButton->setObjectName("noAnimationRadioButton");

        horizontalLayout_11->addWidget(noAnimationRadioButton);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_11);


        gridLayout->addLayout(horizontalLayout_11, 16, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(204, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_5, 17, 1, 1, 1);

        label_5 = new QLabel(ImageViewConfigPage);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 18, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(204, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_6, 19, 1, 1, 1);

        label_6 = new QLabel(ImageViewConfigPage);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_6, 20, 0, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        horizontalRadioButton = new QRadioButton(ImageViewConfigPage);
        horizontalRadioButton->setObjectName("horizontalRadioButton");

        horizontalLayout_12->addWidget(horizontalRadioButton);

        horizontalSpacer_12 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_12);


        gridLayout->addLayout(horizontalLayout_12, 20, 1, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        verticalRadioButton = new QRadioButton(ImageViewConfigPage);
        verticalRadioButton->setObjectName("verticalRadioButton");

        horizontalLayout_13->addWidget(verticalRadioButton);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_13->addItem(horizontalSpacer_13);


        gridLayout->addLayout(horizontalLayout_13, 21, 1, 1, 1);

        label_7 = new QLabel(ImageViewConfigPage);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_7, 22, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        kcfg_ThumbnailBarRowCount = new QSpinBox(ImageViewConfigPage);
        kcfg_ThumbnailBarRowCount->setObjectName("kcfg_ThumbnailBarRowCount");
        kcfg_ThumbnailBarRowCount->setMinimum(1);
        kcfg_ThumbnailBarRowCount->setMaximum(10);

        horizontalLayout_14->addWidget(kcfg_ThumbnailBarRowCount);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_14->addItem(horizontalSpacer_14);


        gridLayout->addLayout(horizontalLayout_14, 22, 1, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 60, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_7, 23, 1, 1, 1);

#if QT_CONFIG(shortcut)
        label_1->setBuddy(surroundingRadioButton);
        label_2->setBuddy(mouseWheelScrollRadioButton);
        label_3->setBuddy(autofitZoomModeRadioButton);
        label_4->setBuddy(glAnimationRadioButton);
        label_6->setBuddy(horizontalRadioButton);
        label_7->setBuddy(kcfg_ThumbnailBarRowCount);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(checkBoardRadioButton, solidColorRadioButton);
        QWidget::setTabOrder(solidColorRadioButton, kcfg_AlphaBackgroundColor);
        QWidget::setTabOrder(kcfg_AlphaBackgroundColor, mouseWheelScrollRadioButton);
        QWidget::setTabOrder(mouseWheelScrollRadioButton, mouseWheelBrowseRadioButton);
        QWidget::setTabOrder(mouseWheelBrowseRadioButton, mouseWheelZoomRadioButton);
        QWidget::setTabOrder(mouseWheelZoomRadioButton, kcfg_EnlargeSmallerImages);
        QWidget::setTabOrder(kcfg_EnlargeSmallerImages, glAnimationRadioButton);
        QWidget::setTabOrder(glAnimationRadioButton, softwareAnimationRadioButton);
        QWidget::setTabOrder(softwareAnimationRadioButton, noAnimationRadioButton);
        QWidget::setTabOrder(noAnimationRadioButton, horizontalRadioButton);
        QWidget::setTabOrder(horizontalRadioButton, verticalRadioButton);
        QWidget::setTabOrder(verticalRadioButton, kcfg_ThumbnailBarRowCount);

        retranslateUi(ImageViewConfigPage);
        QObject::connect(solidColorRadioButton, SIGNAL(toggled(bool)), kcfg_AlphaBackgroundColor, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(ImageViewConfigPage);
    } // setupUi

    void retranslateUi(QWidget *ImageViewConfigPage)
    {
        label_1->setText(tr2i18n("Show transparency with:", nullptr));
        surroundingRadioButton->setText(tr2i18n("Surrounding background", nullptr));
        checkBoardRadioButton->setText(tr2i18n("&Checkerboard background", nullptr));
        solidColorRadioButton->setText(tr2i18n("&Solid color background:", nullptr));
        kcfg_AlphaBackgroundColor->setText(QString());
        label_2->setText(tr2i18n("Mouse wheel behavior:", nullptr));
        mouseWheelScrollRadioButton->setText(tr2i18n("Scroll", "@option:radio action on mouse wheel"));
        mouseWheelBrowseRadioButton->setText(tr2i18n("Browse", "@option:radio action on mouse wheel"));
        mouseWheelZoomRadioButton->setText(tr2i18n("Zoom", "@option:radio action on mouse wheel"));
        label_3->setText(tr2i18n("Zoom mode:", nullptr));
        autofitZoomModeRadioButton->setText(tr2i18n("Autofit each image", nullptr));
        keepSameZoomModeRadioButton->setText(tr2i18n("Keep same zoom and position", nullptr));
        individualZoomModeRadioButton->setText(tr2i18n("Per image zoom and position", nullptr));
        kcfg_EnlargeSmallerImages->setText(tr2i18n("Enlarge smaller images", nullptr));
        label_4->setText(tr2i18n("Animations:", nullptr));
        glAnimationRadioButton->setText(tr2i18n("OpenGL", nullptr));
        softwareAnimationRadioButton->setText(tr2i18n("Software", nullptr));
        noAnimationRadioButton->setText(tr2i18n("None", nullptr));
        label_5->setText(tr2i18n("<b>Thumbnail Bar</b>", nullptr));
        label_6->setText(tr2i18n("Orientation:", nullptr));
        horizontalRadioButton->setText(tr2i18n("Horizontal", nullptr));
        verticalRadioButton->setText(tr2i18n("Vertical", nullptr));
        label_7->setText(tr2i18n("Row count:", nullptr));
        (void)ImageViewConfigPage;
    } // retranslateUi

};

namespace Ui {
    class ImageViewConfigPage: public Ui_ImageViewConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMAGEVIEWCONFIGPAGE_H

