/********************************************************************************
** Form generated from reading UI file 'renamedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RENAMEDIALOG_H
#define UI_RENAMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RenameDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *mFilenameLabel;
    QLineEdit *mFilename;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *mButtonBox;

    void setupUi(QDialog *RenameDialog)
    {
        if (RenameDialog->objectName().isEmpty())
            RenameDialog->setObjectName("RenameDialog");
        RenameDialog->resize(332, 111);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(RenameDialog->sizePolicy().hasHeightForWidth());
        RenameDialog->setSizePolicy(sizePolicy);
        RenameDialog->setMaximumSize(QSize(16777215, 111));
        verticalLayout = new QVBoxLayout(RenameDialog);
        verticalLayout->setObjectName("verticalLayout");
        mFilenameLabel = new QLabel(RenameDialog);
        mFilenameLabel->setObjectName("mFilenameLabel");
        mFilenameLabel->setText(QString::fromUtf8("Rename <filename> to:"));

        verticalLayout->addWidget(mFilenameLabel);

        mFilename = new QLineEdit(RenameDialog);
        mFilename->setObjectName("mFilename");

        verticalLayout->addWidget(mFilename);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        mButtonBox = new QDialogButtonBox(RenameDialog);
        mButtonBox->setObjectName("mButtonBox");
        mButtonBox->setOrientation(Qt::Horizontal);
        mButtonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(mButtonBox);


        retranslateUi(RenameDialog);
        QObject::connect(mButtonBox, &QDialogButtonBox::accepted, RenameDialog, qOverload<>(&QDialog::accept));
        QObject::connect(mButtonBox, &QDialogButtonBox::rejected, RenameDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(RenameDialog);
    } // setupUi

    void retranslateUi(QDialog *RenameDialog)
    {
        RenameDialog->setWindowTitle(tr2i18n("Rename", "@title:window"));
    } // retranslateUi

};

namespace Ui {
    class RenameDialog: public Ui_RenameDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RENAMEDIALOG_H

