/********************************************************************************
** Form generated from reading UI file 'semanticinfosidebaritem.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SEMANTICINFOSIDEBARITEM_H
#define UI_SEMANTICINFOSIDEBARITEM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kratingwidget.h"

QT_BEGIN_NAMESPACE

class Ui_SemanticInfoSideBarItem
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label;
    KRatingWidget *mRatingWidget;
    QLabel *label_2;
    QWidget *mTagContainerWidget;
    QTextEdit *mDescriptionTextEdit;

    void setupUi(QWidget *SemanticInfoSideBarItem)
    {
        if (SemanticInfoSideBarItem->objectName().isEmpty())
            SemanticInfoSideBarItem->setObjectName("SemanticInfoSideBarItem");
        SemanticInfoSideBarItem->resize(231, 183);
        verticalLayout = new QVBoxLayout(SemanticInfoSideBarItem);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(SemanticInfoSideBarItem);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        mRatingWidget = new KRatingWidget(SemanticInfoSideBarItem);
        mRatingWidget->setObjectName("mRatingWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mRatingWidget->sizePolicy().hasHeightForWidth());
        mRatingWidget->setSizePolicy(sizePolicy);
        mRatingWidget->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, mRatingWidget);

        label_2 = new QLabel(SemanticInfoSideBarItem);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        mTagContainerWidget = new QWidget(SemanticInfoSideBarItem);
        mTagContainerWidget->setObjectName("mTagContainerWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mTagContainerWidget->sizePolicy().hasHeightForWidth());
        mTagContainerWidget->setSizePolicy(sizePolicy1);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, mTagContainerWidget);


        verticalLayout->addLayout(formLayout);

        mDescriptionTextEdit = new QTextEdit(SemanticInfoSideBarItem);
        mDescriptionTextEdit->setObjectName("mDescriptionTextEdit");
        mDescriptionTextEdit->setFocusPolicy(Qt::ClickFocus);
        mDescriptionTextEdit->setAcceptRichText(false);

        verticalLayout->addWidget(mDescriptionTextEdit);


        retranslateUi(SemanticInfoSideBarItem);

        QMetaObject::connectSlotsByName(SemanticInfoSideBarItem);
    } // setupUi

    void retranslateUi(QWidget *SemanticInfoSideBarItem)
    {
        label->setText(tr2i18n("Rating:", nullptr));
        label_2->setText(tr2i18n("Tags:", nullptr));
        mDescriptionTextEdit->setPlaceholderText(tr2i18n("Description", nullptr));
        (void)SemanticInfoSideBarItem;
    } // retranslateUi

};

namespace Ui {
    class SemanticInfoSideBarItem: public Ui_SemanticInfoSideBarItem {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SEMANTICINFOSIDEBARITEM_H

