/********************************************************************************
** Form generated from reading UI file 'progresspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROGRESSPAGE_H
#define UI_PROGRESSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ProgressPage
{
public:
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer;
    QLabel *label;
    QProgressBar *mProgressBar;
    QSpacerItem *verticalSpacer_2;
    QDialogButtonBox *mButtonBox;

    void setupUi(QWidget *ProgressPage)
    {
        if (ProgressPage->objectName().isEmpty())
            ProgressPage->setObjectName("ProgressPage");
        ProgressPage->resize(400, 300);
        verticalLayout = new QVBoxLayout(ProgressPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalSpacer = new QSpacerItem(20, 112, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        label = new QLabel(ProgressPage);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        mProgressBar = new QProgressBar(ProgressPage);
        mProgressBar->setObjectName("mProgressBar");
        mProgressBar->setValue(0);

        verticalLayout->addWidget(mProgressBar);

        verticalSpacer_2 = new QSpacerItem(20, 111, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        mButtonBox = new QDialogButtonBox(ProgressPage);
        mButtonBox->setObjectName("mButtonBox");
        mButtonBox->setStandardButtons(QDialogButtonBox::Cancel);

        verticalLayout->addWidget(mButtonBox);


        retranslateUi(ProgressPage);

        QMetaObject::connectSlotsByName(ProgressPage);
    } // setupUi

    void retranslateUi(QWidget *ProgressPage)
    {
        label->setText(tr2i18n("Importing documents...", nullptr));
        (void)ProgressPage;
    } // retranslateUi

};

namespace Ui {
    class ProgressPage: public Ui_ProgressPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROGRESSPAGE_H

